summaryrefslogtreecommitdiff
path: root/src/arch/alpha
diff options
context:
space:
mode:
authorSteve Reinhardt <steve.reinhardt@amd.com>2013-10-15 14:22:43 -0400
committerSteve Reinhardt <steve.reinhardt@amd.com>2013-10-15 14:22:43 -0400
commit219c423f1fb0f9a559bfa87f9812426d5e2c3e29 (patch)
tree7980ae867c4642e710af7cd5d0ad7fe51c0b6687 /src/arch/alpha
parenta830e63de71e5929b8ff8e334bc872faa9193a8b (diff)
downloadgem5-219c423f1fb0f9a559bfa87f9812426d5e2c3e29.tar.xz
cpu: rename *_DepTag constants to *_Reg_Base
Make these names more meaningful. Specifically, made these substitutions: s/FP_Base_DepTag/FP_Reg_Base/g; s/Ctrl_Base_DepTag/Misc_Reg_Base/g; s/Max_DepTag/Max_Reg_Index/g;
Diffstat (limited to 'src/arch/alpha')
-rw-r--r--src/arch/alpha/isa/fp.isa2
-rw-r--r--src/arch/alpha/isa/main.isa6
-rw-r--r--src/arch/alpha/registers.hh8
3 files changed, 8 insertions, 8 deletions
diff --git a/src/arch/alpha/isa/fp.isa b/src/arch/alpha/isa/fp.isa
index 5821ebcc5..e4b4c66c6 100644
--- a/src/arch/alpha/isa/fp.isa
+++ b/src/arch/alpha/isa/fp.isa
@@ -149,7 +149,7 @@ output decoder {{
#ifndef SS_COMPATIBLE_DISASSEMBLY
std::string suffix("");
- suffix += ((_destRegIdx[0] >= FP_Base_DepTag)
+ suffix += ((_destRegIdx[0] >= FP_Reg_Base)
? fpTrappingModeSuffix[trappingMode]
: intTrappingModeSuffix[trappingMode]);
suffix += roundingModeSuffix[roundingMode];
diff --git a/src/arch/alpha/isa/main.isa b/src/arch/alpha/isa/main.isa
index cb43c1357..4d7dccb15 100644
--- a/src/arch/alpha/isa/main.isa
+++ b/src/arch/alpha/isa/main.isa
@@ -224,7 +224,7 @@ output header {{
/// this class and derived classes. Maybe these should really
/// live here and not in the AlphaISA namespace.
enum DependenceTags {
- FP_Base_DepTag = AlphaISA::FP_Base_DepTag
+ FP_Reg_Base = AlphaISA::FP_Reg_Base
};
/// Constructor.
@@ -253,11 +253,11 @@ output decoder {{
void
AlphaStaticInst::printReg(std::ostream &os, int reg) const
{
- if (reg < FP_Base_DepTag) {
+ if (reg < FP_Reg_Base) {
ccprintf(os, "r%d", reg);
}
else {
- ccprintf(os, "f%d", reg - FP_Base_DepTag);
+ ccprintf(os, "f%d", reg - FP_Reg_Base);
}
}
diff --git a/src/arch/alpha/registers.hh b/src/arch/alpha/registers.hh
index 6f0b02c7f..92ba22ee8 100644
--- a/src/arch/alpha/registers.hh
+++ b/src/arch/alpha/registers.hh
@@ -99,10 +99,10 @@ const int TotalNumRegs =
// These enumerate all the registers for dependence tracking.
enum DependenceTags {
// 0..31 are the integer regs 0..31
- // 32..63 are the FP regs 0..31, i.e. use (reg + FP_Base_DepTag)
- FP_Base_DepTag = NumIntRegs,
- Ctrl_Base_DepTag = FP_Base_DepTag + NumFloatRegs,
- Max_DepTag = Ctrl_Base_DepTag + NumMiscRegs + NumInternalProcRegs
+ // 32..63 are the FP regs 0..31, i.e. use (reg + FP_Reg_Base)
+ FP_Reg_Base = NumIntRegs,
+ Misc_Reg_Base = FP_Reg_Base + NumFloatRegs,
+ Max_Reg_Index = Misc_Reg_Base + NumMiscRegs + NumInternalProcRegs
};
} // namespace AlphaISA